==> libro-codemirror-0.1.7.tgz: package/es/editor-contribution.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _dec, _class;
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { CodeEditorContribution } from '@difizen/libro-code-editor';
import { singleton } from '@difizen/mana-app';
import { codeMirrorDefaultConfig } from "./editor.js";
import { codeMirrorEditorFactory } from "./factory.js";
export var CodeMirrorEditorContribution = (_dec = singleton({
  contrib: [CodeEditorContribution]
}), _dec(_class = /*#__PURE__*/function () {
  function CodeMirrorEditorContribution() {
    _classCallCheck(this, CodeMirrorEditorContribution);
    this.factory = codeMirrorEditorFactory;
    this.defaultConfig = codeMirrorDefaultConfig;
  }
  _createClass(CodeMirrorEditorContribution, [{
    key: "canHandle",
    value:
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    function canHandle(mime) {
      // default editor
      return 50;
    }
  }]);
  return CodeMirrorEditorContribution;
}()) || _class);

==> libro-codemirror-0.1.13.tgz: package/es/editor-contribution.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _dec, _class;
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import { CodeEditorContribution } from '@difizen/libro-code-editor';
import { singleton } from '@difizen/mana-app';
import { codeMirrorDefaultConfig } from "./editor.js";
import { codeMirrorEditorFactory } from "./factory.js";
export var CodeMirrorEditorContribution = (_dec = singleton({
  contrib: [CodeEditorContribution]
}), _dec(_class = /*#__PURE__*/function () {
  function CodeMirrorEditorContribution() {
    _classCallCheck(this, CodeMirrorEditorContribution);
    this.factory = codeMirrorEditorFactory;
    this.defaultConfig = codeMirrorDefaultConfig;
  }
  _createClass(CodeMirrorEditorContribution, [{
    key: "canHandle",
    value:
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    function canHandle(mime) {
      // default editor
      return 50;
    }
  }]);
  return CodeMirrorEditorContribution;
}()) || _class);
